==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/GetSolutionConfigPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.GetSolutionConfigPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property migrateProjectName Name of the Azure Migrate project.
 * @property resourceGroupName Name of the Azure Resource Group that migrate project is part of.
 * @property solutionName Unique name of a migration solution within a migrate project.
 */
public data class GetSolutionConfigPlainArgs(
    public val migrateProjectName: String,
    public val resourceGroupName: String,
    public val solutionName: String,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.GetSolutionConfigPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.GetSolutionConfigPlainArgs =
        com.pulumi.azurenative.migrate.inputs.GetSolutionConfigPlainArgs.builder()
            .migrateProjectName(migrateProjectName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .solutionName(solutionName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSolutionConfigPlainArgs].
 */
@PulumiTagMarker
public class GetSolutionConfigPlainArgsBuilder internal constructor() {
    private var migrateProjectName: String? = null

    private var resourceGroupName: String? = null

    private var solutionName: String? = null

    /**
     * @param value Name of the Azure Migrate project.
     */
    @JvmName("jluexxeamgkqatyb")
    public suspend fun migrateProjectName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.migrateProjectName = mapped
    }

    /**
     * @param value Name of the Azure Resource Group that migrate project is part of.
     */
    @JvmName("dsnttoefenxyouyd")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Unique name of a migration solution within a migrate project.
     */
    @JvmName("lmytkxauwaxpmprl")
    public suspend fun solutionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.solutionName = mapped
    }

    internal fun build(): GetSolutionConfigPlainArgs = GetSolutionConfigPlainArgs(
        migrateProjectName = migrateProjectName ?: throw PulumiNullFieldException("migrateProjectName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        solutionName = solutionName ?: throw PulumiNullFieldException("solutionName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/GetSolutionConfigPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.GetSolutionConfigPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property migrateProjectName Name of the Azure Migrate project.
 * @property resourceGroupName Name of the Azure Resource Group that migrate project is part of.
 * @property solutionName Unique name of a migration solution within a migrate project.
 */
public data class GetSolutionConfigPlainArgs(
    public val migrateProjectName: String,
    public val resourceGroupName: String,
    public val solutionName: String,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.GetSolutionConfigPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.GetSolutionConfigPlainArgs =
        com.pulumi.azurenative.migrate.inputs.GetSolutionConfigPlainArgs.builder()
            .migrateProjectName(migrateProjectName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .solutionName(solutionName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSolutionConfigPlainArgs].
 */
@PulumiTagMarker
public class GetSolutionConfigPlainArgsBuilder internal constructor() {
    private var migrateProjectName: String? = null

    private var resourceGroupName: String? = null

    private var solutionName: String? = null

    /**
     * @param value Name of the Azure Migrate project.
     */
    @JvmName("grnlshammtftpdvg")
    public suspend fun migrateProjectName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.migrateProjectName = mapped
    }

    /**
     * @param value Name of the Azure Resource Group that migrate project is part of.
     */
    @JvmName("wmijoidmfawpauba")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Unique name of a migration solution within a migrate project.
     */
    @JvmName("rfbwdgxcmbogvxpd")
    public suspend fun solutionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.solutionName = mapped
    }

    internal fun build(): GetSolutionConfigPlainArgs = GetSolutionConfigPlainArgs(
        migrateProjectName = migrateProjectName ?: throw PulumiNullFieldException("migrateProjectName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        solutionName = solutionName ?: throw PulumiNullFieldException("solutionName"),
    )
}
